#!/usr/bin/env python
#-------------------------------------------------------------
# This script plots denchar output files (systemlabel.CON.SCF,
# systemlabel.CON.DEL, systemlabel.CON.WF#) as 2D contour lines.
#
# Script by Pablo Aguado-Puente (2007)
# pablo.aguado@unican.es
#-------------------------------------------------------------

import sys
import numpy as np
import matplotlib.pyplot as plt

if len(sys.argv) <= 1:
    print('Usage: python contour.py <denchar_file>')
    sys.exit()

# Read the input file where the band structure is stored.
filename = sys.argv[1]

# Read data from the file
data = np.loadtxt(filename)
x, y, z = data[:, 0], data[:, 1], data[:, 2]

# Reshape z to make it 2D
z = z.reshape((len(set(y)), len(set(x))))

# Create a contour plot
plt.contour(x.reshape((len(set(y)), len(set(x)))), y.reshape((len(set(y)), len(set(x)))), z, levels=10, cmap='viridis')

plt.title(filename)
plt.xlabel('x')
plt.ylabel('y')

# Save the plot to a PNG file
plt.savefig('figure-2d-contour.png', format='png', bbox_inches='tight')

plt.show()

sys.exit()

