#!/usr/bin/env python3
# -------------------------------------------------------------
# This script plots denchar output files (systemlabel.CON.SCF,
# systemlabel.CON.DEL, systemlabel.CON.WF#) as 3D surfaces and
# contour lines using matplotlib.
#
# Script by Pablo Aguado-Puente (2007)
# pablo.aguado@unican.es
# -------------------------------------------------------------

import sys
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D

if len(sys.argv) <= 1:
    print('Usage: python3 surf.py <denchar_file>')
    sys.exit()

# Read the input file where the band structure is stored.
filename = sys.argv[1]

# Load data from the file
data = np.loadtxt(filename)

# Extract x, y, and z coordinates from the data
x = data[:, 0]
y = data[:, 1]
z = data[:, 2]

# Create a 3D plot
fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')

# Plot the surface
ax.plot_trisurf(x, y, z, cmap='viridis', edgecolor='k')

# Set plot labels
ax.set_title(filename)
ax.set_xlabel('x')
ax.set_ylabel('y')
ax.set_zlabel('z')

# Save the figure to a file
plt.savefig('figure.png')

# Show the plot
plt.show()

